@@ -54,9 +54,11 @@ class Subtitles:
             self.read_subs()
             cap_file = self.file.split('/')[-1]
             new_captions = f'{cap_file[:-4]}_{lang}{self.suffix}'
-            self.trs_jobs(index, cap_file, lang)
+            if '--progress' not in self.flags:
+                print(self.trs_jobs(index, lang), end='\n\n')
             with open(new_captions, 'w') as new_subs:
-                bar = Bar('Processing', max=len(self.subs_file),
+                bar = Bar(f'{self.trs_jobs(index, lang)}',
+                          max=len(self.subs_file),
                           suffix='%(percent)d%% - %(eta)ds')
                 for line in self.subs_file:
                     if line and not line[0].isdigit():
@@ -71,12 +73,10 @@ class Subtitles:
                 bar.finish()
             self.created_file(new_captions)
 
-    def trs_jobs(self, index, file, lang):
-        '''Printing the current job'''
-        print(f"[{index}/{len(self.dest)}] Subtitles "
-              f"'{file}' translate to {googletrans.LANGUAGES.get(lang)}")
-        if '--progress' not in self.flags:
-            print()
+    def trs_jobs(self, index, lang):
+        '''View the job title'''
+        return (f'[{index}/{len(self.dest)}] '
+                f'Translate into {googletrans.LANGUAGES.get(lang)}')
 
     def print_line_in(self, line):
         '''Print line before translated'''
